"""Quark library."""

__version__ = "0.5.0"

import importlib.util
import logging

from quarklib import config
from quarklib import controls
from quarklib import image
from quarklib import isp
from quarklib import lut
from quarklib.camera import Camera  # type: ignore[attr-defined]
from quarklib.camera import EventManager  # type: ignore[attr-defined]


def get_logger():
    """Get the ``quarklib`` logger."""
    return logging.getLogger("quarklib")


log = get_logger()

__all__ = [
    "config",
    "get_logger",
    "lut",
    "image",
    "isp",
    "controls",
    "Camera",
    "EventManager",
]

if importlib.util.find_spec("cv2") is None:
    log.debug("OpenCV not found, AutoExposure not available")
else:
    from quarklib import ccm

    __all__.append("ccm")
