"""Qtec ISP related functions."""

import importlib.util
import logging

from .calibration import calibrate_black_level
from .isp import create_trigger_sequence
from .white_balance import AutoWhiteBalance
from .white_balance import GreyWorld
from .white_balance import angular_error
from .white_balance import one_shot_auto_white_balance


log = logging.getLogger("quarklib")

__all__ = [
    "create_trigger_sequence",
    "AutoWhiteBalance",
    "GreyWorld",
    "one_shot_auto_white_balance",
    "angular_error",
    "calibrate_black_level",
]

if importlib.util.find_spec("cv2") is None:
    log.debug("OpenCV not found, AutoExposure not available")

else:
    from .auto_exposure import AutoExposure
    from .auto_exposure import SimpleAutoExposure
    from .auto_exposure import one_shot_auto_exposure

    __all__ += [
        "AutoExposure",
        "one_shot_auto_exposure",
        "SimpleAutoExposure",
    ]
